package com.ruoyi.mall.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.MallOrderbackGoodsMapper ;
import com.ruoyi.mall.domain.MallOrderbackGoods ;
import com.ruoyi.mall.service.IMallOrderbackGoodsService ;

/**
 * 退货订单商品Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-02-20
 */
@Service
public class MallOrderbackGoodsServiceImpl implements IMallOrderbackGoodsService 
{
    @Autowired
    private MallOrderbackGoodsMapper mallOrderbackGoodsMapper;

    /**
     * 查询退货订单商品
     * 
     * @param id 退货订单商品主键
     * @return 退货订单商品
     */
    @Override
    public MallOrderbackGoods selectMallOrderbackGoodsById(Long id)
    {
        return mallOrderbackGoodsMapper.selectMallOrderbackGoodsById(id);
    }

    /**
     * 查询退货订单商品列表
     * 
     * @param mallOrderbackGoods 退货订单商品
     * @return 退货订单商品
     */
    @Override
    public List<MallOrderbackGoods> selectMallOrderbackGoodsList(MallOrderbackGoods mallOrderbackGoods)
    {
        return mallOrderbackGoodsMapper.selectMallOrderbackGoodsList(mallOrderbackGoods);
    }

    /**
     * 新增退货订单商品
     * 
     * @param mallOrderbackGoods 退货订单商品
     * @return 结果
     */
    @Override
    public int insertMallOrderbackGoods(MallOrderbackGoods mallOrderbackGoods)
    {
        return mallOrderbackGoodsMapper.insertMallOrderbackGoods(mallOrderbackGoods);
    }

    /**
     * 修改退货订单商品
     * 
     * @param mallOrderbackGoods 退货订单商品
     * @return 结果
     */
    @Override
    public int updateMallOrderbackGoods(MallOrderbackGoods mallOrderbackGoods)
    {
        return mallOrderbackGoodsMapper.updateMallOrderbackGoods(mallOrderbackGoods);
    }

    /**
     * 批量删除退货订单商品
     * 
     * @param ids 需要删除的退货订单商品主键
     * @return 结果
     */
    @Override
    public int deleteMallOrderbackGoodsByIds(Long[] ids)
    {
        return mallOrderbackGoodsMapper.deleteMallOrderbackGoodsByIds(ids);
    }

    /**
     * 删除退货订单商品信息
     * 
     * @param id 退货订单商品主键
     * @return 结果
     */
    @Override
    public int deleteMallOrderbackGoodsById(Long id)
    {
        return mallOrderbackGoodsMapper.deleteMallOrderbackGoodsById(id);
    }
}
