package com.ruoyi.mall.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallOrderbackGoods;
import com.ruoyi.mall.service.IMallOrderbackGoodsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 退货订单商品Controller
 * 
 * @author ruoyi
 * @date 2025-02-20
 */
@RestController
@RequestMapping("/system/goods")
public class MallOrderbackGoodsController extends BaseController
{
    @Autowired
    private IMallOrderbackGoodsService mallOrderbackGoodsService;

    /**
     * 查询退货订单商品列表
     */
    @PreAuthorize("@ss.hasPermi('system:goods:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallOrderbackGoods mallOrderbackGoods)
    {
        startPage();
        List<MallOrderbackGoods> list = mallOrderbackGoodsService.selectMallOrderbackGoodsList(mallOrderbackGoods);
        return getDataTable(list);
    }

    /**
     * 导出退货订单商品列表
     */
    @PreAuthorize("@ss.hasPermi('system:goods:export')")
    @Log(title = "退货订单商品", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MallOrderbackGoods mallOrderbackGoods) throws IOException {
        List<MallOrderbackGoods> list = mallOrderbackGoodsService.selectMallOrderbackGoodsList(mallOrderbackGoods);
        ExcelUtil<MallOrderbackGoods> util = new ExcelUtil<MallOrderbackGoods>(MallOrderbackGoods.class);
        util.exportExcel(response, list, "退货订单商品数据");
    }

    /**
     * 获取退货订单商品详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:goods:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        MallOrderbackGoods mallOrderbackGoods = mallOrderbackGoodsService.selectMallOrderbackGoodsById(id);
        return  AjaxResult.success(mallOrderbackGoods);
    }

    /**
     * 新增退货订单商品
     */
    @PreAuthorize("@ss.hasPermi('system:goods:add')")
    @Log(title = "退货订单商品", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallOrderbackGoods mallOrderbackGoods)
    {
        return toAjax(mallOrderbackGoodsService.insertMallOrderbackGoods(mallOrderbackGoods));
    }

    /**
     * 修改退货订单商品
     */
    @PreAuthorize("@ss.hasPermi('system:goods:edit')")
    @Log(title = "退货订单商品", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallOrderbackGoods mallOrderbackGoods)
    {
        return toAjax(mallOrderbackGoodsService.updateMallOrderbackGoods(mallOrderbackGoods));
    }

    /**
     * 删除退货订单商品
     */
    @PreAuthorize("@ss.hasPermi('system:goods:remove')")
    @Log(title = "退货订单商品", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallOrderbackGoodsService.deleteMallOrderbackGoodsByIds(ids));
    }
}
